Image untagger
==============

.. py:module:: pubtools._quay.image_untagger

.. autoclass:: ImageUntagger

   .. automethod:: __init__
   .. automethod:: set_quay_client
   .. automethod:: get_repository_tags_mapping
   .. automethod:: construct_tag_digest_mappings
   .. automethod:: get_lost_digests
   .. automethod:: untag_images
